import React, { useState, useRef, Fragment, useEffect } from "react";
import NewPage from '@/components/NewPage';
import * as $$ from '@/utils/utility';
import "@arco-themes/react-gzzz/css/arco.css";
import '../index.less';
import { Tabs } from '@arco-design/web-react';
import { examine, Matter, transfer, applyRecord } from '@/assets/images'
import EventFlow from '../eventFlow/component/EventFlow';
import ApplyInfo from "../matterDetail/ApplyInfo";
import { useParams } from 'react-router-dom';
import ReviewExamine from './component/ReviewExamine';

const TabPane = Tabs.TabPane;

function getTabButton(data) {
	return $$.ax.request({ url: `caseTask/getTabButton`, type: 'get', service: 'mediate', data });
}

const myTab = [
	{
		img: Matter,
		label: '事项详情',
		key: 'sxxq',
	},
	{
		img: applyRecord,
		label: '申请记录',
		key: 'sqjl',
	},
	{
		img: examine,
		label: '结案审核',
		key: 'jash',
	},
]
const ClosingReview = () => {
	const routeData = useParams();
	const [authorData, setAuthorData] = useState({});
	const [tabsList, setTabsList] = useState([]);
	const [tabsActive, setTabsActive] = useState();

	useEffect(() => {
		getAuthor()
	}, [])

	//获取权限tab和按钮权限
	const getAuthor = async () => {
		const res = await getTabButton({
			caseTaskId: routeData.caseTaskId
		})
		if (res.type) {
			const { tabList } = res.data
			setAuthorData(res.data)
			if (tabList.length === 0) {
				//没有tab就不展示
			} else {
				setTabsList(myTab.filter(item => {
					const flag = tabList.some(result => {
						if (result.id === item.key) {
							return true
						}
					})
					return flag
				}))
				setTabsActive(tabList[0].id)
			}
		}
	}

	//根据id定义组件
	const getTypeDom = (key) => {
		if (key === 'dslxq' || key === 'sxxq') {
			return <EventFlow authorData={authorData} caseId={routeData.caseId} />
		}
		if (key === 'sqjl') {
			return <ApplyInfo />
		}
		if (key === 'jash') {
			return <ReviewExamine type={key} />
		}
	}

	return (
		<div style={{ position: 'relative' }}>
			<NewPage
				pageHead={
					{ breadcrumbData: [{ title: '工作台' }, { title: '事件中心' }], title: '处理' }
				}
			>
				<Tabs
					onChange={(v) => setTabsActive(v)}
					className='myTabContent'
					activeTab={tabsActive}
				>
					{tabsList?.map(item => {
						return <TabPane
							key={item.key}
							title={
								<span>
									{tabsActive === item.key && <img src={item.img} alt="" style={{ width: '16px', height: '16px', margin: '-5px 12px 0px 0px' }} />}
									<span style={{ fontSize: '16px' }}>{item.label}</span>
								</span>
							}
						>
							{getTypeDom(item.key)}
						</TabPane>
					})}
				</Tabs>
			</NewPage>
		</div>
	)
}

export default ClosingReview;